Page MenuHomeDevCentral

D2413.id6069.diff
No OneTemporary

D2413.id6069.diff

diff --git a/js/app.js b/js/app.js
--- a/js/app.js
+++ b/js/app.js
@@ -16,7 +16,7 @@
- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
:: Keyboard events
- :: Keyboard shorcuts help
+ :: Keyboard shortcuts help
*/
@@ -32,9 +32,9 @@
).then(
function (sites) {
for (var i = 0 ; i < sites.length ; i++) {
//Press g, <site.shorcutKey> to directly go to this site.
(function(site) {
- Mousetrap.bind('g ' + site.shorcutKey, function() {
+ Mousetrap.bind('g ' + site.shortcutKey, function() {
var url = "//" + site.id + ".nasqueron.org";
document.location.href = url;
});
@@ -48,7 +48,7 @@
});
/* -------------------------------------------------------------
- Keyboard shorcuts help
+ Keyboard shortcuts help
Based on QuestionMark.js by Louis Lazaris
http://impressivewebs.github.io/QuestionMark.js/
@@ -72,12 +72,12 @@
var resizeHelpWindowTimeout = null;
/**
* Initializes keyboard shorcuts help
*
* @param string content The HTML content of the help window
*/
- function initializeKeyboardShorcuts (content) {
- //Places keyboard shorcuts element in DOM
+ function initializeKeyboardShortcuts (content) {
+ //Places keyboard shortcuts element in DOM
domConstruct.place(content, dojo.body(), "last");
resizeHelpWindow();
@@ -174,9 +174,9 @@
//Reads help file and initializes help
request("question.mark.html").then(
- initializeKeyboardShorcuts,
+ initializeKeyboardShortcuts,
function (err) {
- console.log("Error fetching Keyboard shorcuts help: ", err);
+ console.log("Error fetching Keyboard shortcuts help: ", err);
}
);
});
@@ -32,9 +32,9 @@
function (sites) {
for (var i = 0 ; i < sites.length ; i++) {
- //Press g, <site.shorcutKey> to directly go to this site.
+ //Press g, <site.shortcutKey> to directly go to this site.
(function(site) {
@@ -72,12 +72,12 @@
var resizeHelpWindowTimeout = null;
/**
- * Initializes keyboard shorcuts help
+ * Initializes keyboard shortcuts help
*
* @param string content The HTML content of the help window

File Metadata

Mime Type
text/plain
Expires
Fri, Nov 22, 07:49 (9 h, 58 m)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
2255873
Default Alt Text
D2413.id6069.diff (1 KB)

Event Timeline